package de.telefonbuch.model;

import org.jetbrains.annotations.NotNull;

import java.rmi.RemoteException;
import java.rmi.registry.LocateRegistry;
import java.rmi.registry.Registry;
import java.rmi.server.UnicastRemoteObject;

public class Server implements IServer {

	public Sqlite sqlite;

	public Server(Sqlite sqlite) {
		this.sqlite = sqlite;
	}

	public void start(Server server) {
		try {
			// Neues Objekt erstellen, das zur Registry exportiert werden soll
			IServer stub = (IServer) UnicastRemoteObject.exportObject(server, 0);

			// Das exportierte Objekt an die Registry binden
			// Standard-Port der Registry: 1099
			Registry registry = LocateRegistry.createRegistry(Registry.REGISTRY_PORT);
			registry.rebind("RMI-Server", stub); // rebind überschreibt ein evtl schon gebundenes Objekt
		} catch (RemoteException e) {
			e.printStackTrace();
		}
	}

	public void addKontakt(@NotNull Kontakt kontakt) {
		sqlite.addKontakt(kontakt);
	}

	public void deleteKontakt(String telefon) {
		sqlite.deleteKontakt(telefon);
	}

	public Kontakt getKontakt(@NotNull String telefon) {
		return sqlite.getKontakt(telefon);
	}

	public String[] getNavi(String telefon) {
		return sqlite.getNavi(telefon);
	}

	public int countKontakte() {
		return sqlite.countKontakte();
	}

	@Override
	public void methodenaufruf() throws RemoteException {
		System.out.println("Aufruf von Methode 'methodenaufruf()'");
	}

	@Override
	public String methodeMitRueckgabe() throws RemoteException {
		System.out.println("Aufruf von Methode 'methodeMitRueckgabe()'");
		return "Hallo Client!";
	}

	@Override
	public void methodeMitParameter(String text) throws RemoteException {
		System.out.println("Aufruf von Methode 'methodeMitParameter()' mit Parameter: " + text);
	}

	@Override
	public boolean interaktion(String text) throws RemoteException {
		System.out.println("Aufruf von Methode 'interaktion()' mit Parameter: " + text);
		return true;
	}

}